/*****************************************************************************
Deng, Minjie and Fang, Min (2021) 
``Debt Maturity and Investment Responses to Monetary Policy''.

Program: 00_Do-Construct_FRED
Purpose: pulls all raw data that comes from online sources.

Code Modified from Ottonello and Winberry (2021) ECTA Paper
``Financial Heterogeneity and the Investment Channel of Monetary Policy'' 
Program: import_online.do
Program: import_FRED.do
*****************************************************************************/

clear all
set more off
capture log close

ssc install freduse


****************************************
* 1. Import quarterl aggregates from FRED
****************************************

freduse PNFI A008RD3Q086SBEA, clear

compress
save "2_data_raw/FRED_quarterly.dta", replace


****************************************
* 2. Import monthly aggregates from FRED
****************************************

freduse GDPC1 UNRATE IPDNBS CPIAUCSL VIXCLS FEDFUNDS, clear

compress
save "2_data_raw/FRED_monthly.dta", replace



****************************************
* 3. FRED yields and spreads
****************************************

freduse DGS3MO DGS1, clear

compress
save "2_data_raw/FRED_daily.dta", replace


****************************************
* 4. Construct quarterly aggregate time series from monthly time series
****************************************

use "2_data_raw/FRED_monthly.dta", clear
gen dateq = qofd(daten)
format dateq %tq

rename (GDPC1 UNRATE IPDNBS CPIAUCSL VIXCLS FEDFUNDS) (gdp ur ipd cpi vix ffr)
collapse (mean) gdp ur ipd cpi vix ffr, by(dateq)

// Housekeeping
la var gdp "Real gross domestic product (SA)"
la var ur "Unemployment rate (SA)"
la var ipd "Nonfarm business sector: implicit price deflator (SA)"
la var cpi "Consumer Price Index for All Urban Consumers: All Items (SA)"
la var vix "CBOE Volatility Index: VIX"
la var ffr "Effective FFR"

// Generate transformations
tsset dateq
gen dlog_gdp = log(gdp) - log(L.gdp)
gen dlog_cpi = log(cpi) - log(L.cpi)

compress
save "5_temp/FRED_quarterly.dta", replace


****************************************
* 5. Import daily series
****************************************


* Pull Treasury yields
use "2_data_raw/FRED_daily.dta", clear
keep daten DGS3MO DGS1
rename daten dated
sort dated
order dated DGS3MO DGS1

compress
save "5_temp/FRED_tyields.dta", replace
















