/*****************************************************************************
Deng, Minjie and Fang, Min (2021) 
``Debt Maturity and Investment Responses to Monetary Policy''.

Program: 01_Do-Construct_age

Code Modified from Ottonello and Winberry (2021) ECTA Paper
``Financial Heterogeneity and the Investment Channel of Monetary Policy'' 
Program: construct_age.do
*****************************************************************************/

clear all
set more off
set scheme s1color
capture log close



/**********************************************************************
I_ Import Datastream Data
**********************************************************************/

* Import company starting dates from Datastream (Worldscope Fundamentals Annual)
* variables: cusip, date of incorporation
use "2_data_raw/worldscope_raw.dta", clear
drop code year_ freq
rename ITEM6004 cusip
rename ITEM18273 DATEOFINCORPORATION
// Remove observations missing CUSIP or Date of Incorporation
drop if cusip=="NA"|DATEOFINCORPORATION==.
// Clean CUSIP codes so they are uniformly 9-digits
gen cusip_length = length(cusip)
replace cusip = "000"+cusip if cusip_length==6
replace cusip = "00"+cusip if cusip_length==7
replace cusip = "0"+cusip if cusip_length==8
// Clean date variable into year, month, and date
gen year = year(DATEOFINCORPORATION)
gen month = month(DATEOFINCORPORATION)
gen day = day(DATEOFINCORPORATION)
// Construct quarterly date of incorporation
gen quarter = 1 if inrange(month,1,3)
replace quarter = 2 if inrange(month,4,6)
replace quarter = 3 if inrange(month,7,9)
replace quarter = 4 if inrange(month,10,12)
replace quarter = 1 if mi(month) // Assume that companies with missing monthly data were incorporated in January of that year
gen dateq = yq(year,quarter)
format dateq %tq
// Make data unique by CUSIP
keep cusip dateq // Only keep year of incorporation since either month and/or date are missing for ~15% of sample
duplicates drop
// Keep earliest year for CUSIPs with multiple incorporation years
bys cusip: egen min_dateq = min(dateq)
keep cusip min_dateq
duplicates drop
duplicates report cusip
assert `r(N)'==`r(unique_value)'
rename min_dateq inc_dateq
format inc_dateq %tq
lab var inc_dateq "Date of incorporation (Datastream)"

compress
save "5_temp/DS_yearinc.dta", replace

/**********************************************************************
II_ Match Gvkey
**********************************************************************/

clear all
set more off
set scheme s1color
capture log close


use "2_data_raw/compustat_quarterly_raw_long.dta", clear
keep gvkey cusip
duplicates drop
drop if cusip == ""
merge 1:1 cusip using "5_temp/DS_yearinc.dta"
drop if inc_dateq == .
drop _merge

destring gvkey, replace
duplicates drop gvkey, force

save "3_data_constructed/DS_yearinc.dta", replace







