/*****************************************************************************
Deng, Minjie and Fang, Min (2021) 
``Debt Maturity and Investment Responses to Monetary Policy''.

Program: 00_Do-Construct_monetary_policy_shocks
Purpose: Generates datasets with consolidated high frequency monetary
shocks on daily frequency and unexpected monetary shocks on quarterly
frequency.
*****************************************************************************/

***************************************************
*I.1 30days FFR shocks from Weber AER 2016 + Swan IJCB 2005
*    Aggregate to quarterly both sum in Wong(2016) and smoothed in Ottonello and Winberry(2017)

clear
use 2_data_raw/ffr30_raw.dta
gen omega_a=(days-tau)/days
gen omega_b=tau/days
gen current_smooth_tight=omega_a*tight
gen lag_smooth_tight=omega_b*tight
egen sum_current_smooth_tight=total(current_smooth_tight), by (year quarter)
egen sum_lag_smooth_tight=total(lag_smooth_tight), by (year quarter)
gen current_smooth_wide=omega_a*wide
gen lag_smooth_wide=omega_b*wide
egen sum_current_smooth_wide=total(current_smooth_wide), by (year quarter)
egen sum_lag_smooth_wide=total(lag_smooth_wide), by (year quarter)
drop date time tight wide days tau omega_a omega_b
drop current_smooth_tight lag_smooth_tight current_smooth_wide lag_smooth_wide
drop Month
duplicates drop
gen smoothed_tight=sum_current_smooth_tight+sum_lag_smooth_tight[_n-1]
gen smoothed_wide=sum_current_smooth_wide+sum_lag_smooth_wide[_n-1]
drop sum_current_smooth_tight sum_lag_smooth_tight sum_current_smooth_wide sum_lag_smooth_wide
rename smoothed_tight tight_smo
rename smoothed_wide wide_smo
save 5_temp/ffr30_quarter.dta, replace

***************************************************
*I.2 30days FFR shocks while excluding complementary central bank information shock from Jarocinski and Karadi(2020)
*    Aggregate to quarterly

clear
import delimited using 2_data_raw/Jarocinski_Karadi_2020_data_fig4.csv, clear
gen quarter = 1 if period == 2 | period == 3 | period == 4
replace quarter = 2 if period == 5 | period == 6 | period == 7
replace quarter = 3 if period == 8 | period == 9 | period == 10
replace quarter = 4 if period == 11 | period == 12 | period == 13
keep year quarter mpshocksign cbishocksign
bysort year quarter: egen mp_jk = total(mpshocksign)
bysort year quarter: egen cbi_jk = total(cbishocksign)
keep year quarter mp_jk cbi_jk
duplicates drop
drop if quarter == .
*adjust to basis points
replace mp_jk = mp_jk * 100
replace cbi_jk = cbi_jk * 100
save 5_temp/jk_quarter.dta, replace

***************************************************
*I.3 Merge shocks and adjust units

merge 1:1 year quarter using 5_temp/ffr30_quarter.dta
drop _merge

sort year quarter 
rename tight_sum tsum
rename wide_sum wsum
rename tight_smo tsmo
rename wide_smo wsmo
duplicates drop

save 3_data_constructed/shocks.dta, replace
















