*---------------------------------
******* Summary Statistics *******
*---------------------------------

* Part1: Event SHOCKS  & Quarterly SHOCKS
*-------------------------------------------------------------------------------------------------------------
*-- Event SHOCKS
clear all
set more off
set scheme s1color
capture log close
use "2_data_raw/ffr30_raw.dta",clear

*- Summary
sum tight, d
sum wide, d

*-- Quarterly SHOCKS
clear all
set more off
set scheme s1color
capture log close
use "3_data_constructed/shocks.dta",clear

*- Summary MAIN
sum tsum, d
sum wsum, d

*- Summary Appendix
drop if year>2008
sum tsmo, d
sum wsmo, d
sum mp_jk, d

*-- Correlation
corr tsum wsum tsmo wsmo mp_jk
pwcorr tsum wsum tsmo wsmo mp_jk, sig star(.05)

*- Time Series PLOT (manually saved Figure a1)
gen dateq = yq(year, quarter)
format dateq %tq
drop if year>2008
line tsum dateq


* Part2: Firm Level 
*-------------------------------------------------------------------------------------------------------------
clear
set more off
use "3_data_constructed/sample.dta",clear
codebook borrow longborrow shortborrow

*- Summary key variables
sum inv, d
sum mat, d
sum borrow, d
sum longborrow, d
sum shortborrow, d

*- Summary key control variables
sum lev, d
sum d2d, d
sum age, d
sum liq, d
sum atq, d
sum cheq, d

*- Correlation key control variables
corr mat lev d2d age liq atq cheq
pwcorr mat lev d2d age liq atq cheq, sig star(.05)


*- Histogram
histogram maturity
gr_edit .xaxis1.title.text = {}
gr_edit .xaxis1.title.text.Arrpush Fraction of Long-term Debt over Total Debt
gr_edit .plotregion1.plot1.style.editstyle area(linestyle(color(white))) editcopy
gr_edit .plotregion1.plot1.style.editstyle area(shadestyle(color(gs5))) editcopy
gr_edit .plotregion1.plot1.style.editstyle area(linestyle(width(vthin))) editcopy
gr_edit .plotregion1.plot1.bar_size = 0.014
gr_edit .style.editstyle declared_ysize(6) editcopy
gr_edit .style.editstyle declared_xsize(6) editcopy
graph save 4_results/01_Graph/Figure_1_a.gph, replace
graph export 4_results/01_Graph/Figure_1_a.eps, replace



* Part3: Time SERIES
*-------------------------------------------------------------------------------------------------------------
clear
set more off
use "2_data_raw/FOF_csv_files/data_FFH.dta",clear
twoway line F date_q
gr_edit .xaxis1.title.text = {}
gr_edit .xaxis1.title.text.Arrpush Time
gr_edit .yaxis1.title.text = {}
gr_edit .yaxis1.title.text.Arrpush Fraction of Long-term Debt at Aggregate-level
gr_edit .xaxis1.reset_rule 10, tickset(major) ruletype(suggest) 
gr_edit .xaxis1.reset_rule , tickset(major) ruletype(minmax) 
gr_edit .plotregion1.plot1.style.editstyle line(width(medthick)) editcopy
gr_edit .plotregion1.plot1.style.editstyle line(color(black)) editcopy
gr_edit .style.editstyle declared_ysize(6) editcopy
gr_edit .style.editstyle declared_xsize(6) editcopy
gr_edit .xaxis1.style.editstyle majorstyle(tickstyle(textstyle(size(small)))) editcopy
gr_edit .xaxis1.reset_rule 120 232 16 , tickset(major) ruletype(range) 
graph save 4_results/01_Graph/Figure_1_b.gph, replace
graph export 4_results/01_Graph/Figure_1_b.eps, replace



















