* We are going to look at how firms responses to monetary policy shocks gien their financial positions
* Financial positions we are discussing here is (leverage, maturity)
* Firms responses are (investment, borrowing, leverage choice, maturity choice)
clear
set more off
use "3_data_constructed/sample.dta",clear
xtset gvkey time

*----------------------------------------------------------------------
* Takeout Average Mean of Sample
replace leverage = leverage-0.351701
replace maturity = maturity-0.8421202

*----------------------------------------------------------------------
egen mean_leverage=mean(leverage), by (gvkey)
egen mean_maturity=mean(maturity), by (gvkey)
egen mean_d2default=mean(d2default), by (gvkey)
egen mean_age=mean(age), by (gvkey)
egen mean_liquidity=mean(liquidity), by (gvkey)
gen temp_leverage=leverage - mean_leverage
gen temp_maturity=maturity - mean_maturity
gen temp_d2default=d2default - mean_d2default
gen temp_age=age - mean_age
gen temp_liquidity=liquidity - mean_liquidity

*----------------------------------------------------------------------
** adjust logk - logk_t-1
sort gvkey time
order gvkey time inv
gen logk = inv if gvkey != gvkey[_n-1]
order gvkey time inv logk
replace logk = logk[_n-1] + inv if logk==. & gvkey == gvkey[_n-1]
order gvkey time inv logk 
                          

**************************************************************
*Local Projections 			
**************************************************************

*******************
** Set-up of LPs **
*******************						  
***** number of lags | horizon
local MaxLPLags 0
local horizon 12					  
						  
***** LHS variable: the response variable
sort gvkey time
forvalues i=0/`horizon' {
	
	gen logk`i' = (f`i'.logk - l.logk)

}						  
						  
***** variables to store the impulse response 
*(vector of betas from the LP regressions) and standard errors
gen b_mattsum=.
gen b_tsum=.
gen se_mattsum=.
gen se_tsum=.					  
						  
***** controls in LP regression
local rhs_controls   l(0/`MaxLPLags').atq l(0/`MaxLPLags').cheq l(0/`MaxLPLags').revtq l(0/`MaxLPLags').saleq ///
                     l(0/`MaxLPLags').sale_g l(0/`MaxLPLags').profit l(0/`MaxLPLags').vol l(0/`MaxLPLags').nei  ///
                     l(0/`MaxLPLags').vixq l(0/`MaxLPLags').GDP_Growth l(0/`MaxLPLags').Unemployment ///
					 l(0/`MaxLPLags').inflation 


****************************************************************
*** Baseline LP table Using OLS
****************************************************************
***** Gen interaction terms
gen lag_temp_mat_tsum = l.temp_maturity*tsum


***** One regression for each horizon of the response (0-12 quarters)
forvalues i=0/`horizon' {	
	
	***** LP regression
	*** 
	reghdfe logk`i' tsum lag_temp_mat_tsum l.temp_maturity  ///
	l.leverage l.maturity ///
    `rhs_li_controls', absorb(gvkey sic2 quarter time) cluster(gvkey time)
	eststo ols_logk`i'
	
    replace b_mattsum=_b[lag_temp_mat_tsum]  if _n == `i'+1
    replace se_mattsum=_se[lag_temp_mat_tsum]  if _n == `i'+1

		  
}
	
			
****************************************************************
*** Baseline OLS LP graphs
****************************************************************
local horizon 12	
gen Quarters = _n-1 if _n <= `horizon' +1
* zero line
gen zero = 0 if _n <= `horizon' +1
***** create confidence bands (in this case 90%) ****
scalar sig = 0.10	 // specify significance level	
gen up_mattsum = b_mattsum + invnormal(1-sig/2)*se_mattsum if _n <= (`horizon' + 1)
gen dn_mattsum = b_mattsum - invnormal(1-sig/2)*se_mattsum if _n <= (`horizon' + 1)
	
************************ Plot
	twoway (line b_mattsum Quarters, lcolor(navy) ///
	lpattern(solid) lwidth(medthick)) /// 
	(line up_mattsum Quarters, lcolor(navy) ///
	lpattern(dash) lwidth(thin)) /// 
	(line dn_mattsum Quarters, lcolor(navy) ///
	lpattern(dash) lwidth(thin)) /// 
	(line zero Quarters, lcolor(black)), ///
	ytitle("Interaction coefficient", size(medsmall)) ///
	xtitle("Quarters since shock", size(medsmall))  
	gr_edit .xaxis1.reset_rule 0 12 1 , tickset(major) ruletype(range) 
    gr_edit .xaxis1.style.editstyle draw_major_grid(yes) editcopy
    gr_edit .xaxis1.reset_rule 0 12 1 , tickset(major) ruletype(range) 
    gr_edit .legend.draw_view.setstyle, style(no)
    gr_edit .yaxis1.style.editstyle draw_major_grid(yes) editcopy	
	graph save 4_results/01_Graph/Figure_2.gph, replace
	graph export 4_results/01_Graph/Figure_2.eps, replace
	
	
	
	


				  
						  
						  
						  
						  
						  
		
