*---------------------------------------------------------------------------------------------
*---------------------------------------------------------------------------------------------
*---------------------------------------------------------------------------------------------
****** Part I:Concerns of Variation in Monetary Policy Shocks --------------------------------
*---------------------------------------------------------------------------------------------
*---------------------------------------------------------------------------------------------
*---------------------------------------------------------------------------------------------
clear
set more off
use "3_data_constructed/sample.dta",clear
codebook borrow longborrow shortborrow

*----------------------------------------------------------------------
* Takeout Average Mean
replace leverage = leverage-0.351701
replace maturity = maturity-0.8421202

*----------------------------------------------------------------------
*sort gvkey time
*gen counting = 1 
*bysort gvkey: egen counts = total(counting)
*drop if counts<10

*----------------------------------------------------------------------
egen mean_leverage=mean(leverage), by (gvkey)
egen mean_maturity=mean(maturity), by (gvkey)
egen mean_d2default=mean(d2default), by (gvkey)
egen mean_age=mean(age), by (gvkey)
egen mean_liquidity=mean(liquidity), by (gvkey)
gen temp_leverage=leverage - mean_leverage
gen temp_maturity=maturity - mean_maturity
gen temp_d2default=d2default - mean_d2default
gen temp_age=age - mean_age
gen temp_liquidity=liquidity - mean_liquidity

************************************************************************
***** Robustness Check NO.1: Alternative Measure ***********************
***** Shocks by Time Window: Tight to Wide       ***********************
************************************************************************
replace tsum = wsum

* (1) MP Only  | Firm Control [Yes], Aggregate Control [Yes]
set more off
xtset gvkey time
reghdfe inv tsum l.temp_maturity l.temp_leverage  ///
        l.atq l.cheq l.revtq l.saleq l.sale_g l.profit l.vol l.nei ///
		l.vixq l.GDP_Growth l.Unemployment l.inflation, ///
		absorb(gvkey sic2 quarter) cluster(gvkey time)
estimates store a1, title(A1)

* (2) Maturity Only | Firm Control [Yes], Aggregate Control [Yes]
set more off
xtset gvkey time
reghdfe inv tsum (c.l.temp_maturity)#(c.tsum)  ///
        l.temp_maturity l.temp_leverage   ///
        l.atq l.cheq l.revtq l.saleq l.sale_g l.profit l.vol l.nei ///
		l.vixq l.GDP_Growth l.Unemployment l.inflation, ///
		absorb(gvkey sic2 quarter) cluster(gvkey time)
estimates store a2, title(A2)

* (3) Maturity + Lev + Time FE | Firm Control [Yes], Aggregate Control [Yes]
set more off
xtset gvkey time
reghdfe inv tsum (c.l.temp_maturity)#(c.tsum) (c.tsum)#(c.l.temp_leverage)  ///
        l.temp_maturity l.temp_leverage ///
        l.atq l.cheq l.revtq l.saleq l.sale_g l.profit l.vol l.nei ///
		l.vixq l.GDP_Growth l.Unemployment l.inflation, ///
		absorb(gvkey sic2 quarter time) cluster(gvkey time)
estimates store a3, title(A3)

* (4) Maturity + DD + Time FE| Firm Controls [Yes], Aggregate Control [Yes]
set more off
xtset gvkey time
reghdfe inv tsum (c.l.temp_maturity)#(c.tsum) (c.tsum)#(c.l.temp_d2default)  ///
        l.temp_maturity l.temp_d2default  ///
        l.atq l.cheq l.revtq l.saleq l.sale_g l.profit l.vol l.nei ///
		l.vixq l.GDP_Growth l.Unemployment l.inflation, ///
		absorb(time gvkey sic2 quarter) cluster(gvkey time)
estimates store a4, title(A4)

* (5) Maturity + Others | Firm Control [Yes], Aggregate Control [Yes]
set more off
xtset gvkey time
reghdfe inv tsum (c.l.temp_maturity)#(c.tsum) (c.tsum)#(c.l.temp_leverage) (c.tsum)#(c.l.temp_d2default)  ///
        l.temp_maturity  l.temp_leverage l.temp_d2default ///
        l.atq l.cheq l.revtq l.saleq l.sale_g l.profit l.vol l.nei ///
		l.vixq l.GDP_Growth l.Unemployment l.inflation, ///
		absorb(gvkey sic2 quarter) cluster(gvkey time)
estimates store a5, title(A5)

* (6) Maturity + Others + Time FE | Firm Controls [Yes], Aggregate Control [Yes]
set more off
xtset gvkey time
reghdfe inv tsum (c.l.temp_maturity)#(c.tsum) (c.tsum)#(c.l.temp_leverage) (c.tsum)#(c.l.temp_d2default)  ///
        l.temp_maturity l.temp_leverage l.temp_d2default ///
        l.atq l.cheq l.revtq l.saleq l.sale_g l.profit l.vol l.nei ///
		l.vixq l.GDP_Growth l.Unemployment l.inflation, ///
		absorb(time gvkey sic2 quarter) cluster(gvkey time)
estimates store a6, title(A6)

* Export Table 6 in appendix
esttab a1 a2 a3 a4 a5 a6 using 4_results/03_Table_Robustness/Table_a6.tex, replace  ///
se b(3) ar2 starlevels(* .1 ** 0.05 *** 0.01)



************************************************************************
***** Robustness Check NO.2: Alternative Measure ***********************
***** Shocks by Time Window: Smoothed Aggregation      *****************
************************************************************************
replace tsum = tsmo

* (1) MP Only  | Firm Control [Yes], Aggregate Control [Yes]
set more off
xtset gvkey time
reghdfe inv tsum l.temp_maturity l.temp_leverage  ///
        l.atq l.cheq l.revtq l.saleq l.sale_g l.profit l.vol l.nei ///
		l.vixq l.GDP_Growth l.Unemployment l.inflation, ///
		absorb(gvkey sic2 quarter) cluster(gvkey time)
estimates store a1, title(A1)

* (2) Maturity Only | Firm Control [Yes], Aggregate Control [Yes]
set more off
xtset gvkey time
reghdfe inv tsum (c.l.temp_maturity)#(c.tsum)  ///
        l.temp_maturity l.temp_leverage   ///
        l.atq l.cheq l.revtq l.saleq l.sale_g l.profit l.vol l.nei ///
		l.vixq l.GDP_Growth l.Unemployment l.inflation, ///
		absorb(gvkey sic2 quarter) cluster(gvkey time)
estimates store a2, title(A2)

* (3) Maturity + Lev + Time FE | Firm Control [Yes], Aggregate Control [Yes]
set more off
xtset gvkey time
reghdfe inv tsum (c.l.temp_maturity)#(c.tsum) (c.tsum)#(c.l.temp_leverage)  ///
        l.temp_maturity l.temp_leverage ///
        l.atq l.cheq l.revtq l.saleq l.sale_g l.profit l.vol l.nei ///
		l.vixq l.GDP_Growth l.Unemployment l.inflation, ///
		absorb(gvkey sic2 quarter time) cluster(gvkey time)
estimates store a3, title(A3)

* (4) Maturity + DD + Time FE| Firm Controls [Yes], Aggregate Control [Yes]
set more off
xtset gvkey time
reghdfe inv tsum (c.l.temp_maturity)#(c.tsum) (c.tsum)#(c.l.temp_d2default)  ///
        l.temp_maturity l.temp_d2default  ///
        l.atq l.cheq l.revtq l.saleq l.sale_g l.profit l.vol l.nei ///
		l.vixq l.GDP_Growth l.Unemployment l.inflation, ///
		absorb(time gvkey sic2 quarter) cluster(gvkey time)
estimates store a4, title(A4)

* (5) Maturity + Others | Firm Control [Yes], Aggregate Control [Yes]
set more off
xtset gvkey time
reghdfe inv tsum (c.l.temp_maturity)#(c.tsum) (c.tsum)#(c.l.temp_leverage) (c.tsum)#(c.l.temp_d2default)  ///
        l.temp_maturity  l.temp_leverage l.temp_d2default ///
        l.atq l.cheq l.revtq l.saleq l.sale_g l.profit l.vol l.nei ///
		l.vixq l.GDP_Growth l.Unemployment l.inflation, ///
		absorb(gvkey sic2 quarter) cluster(gvkey time)
estimates store a5, title(A5)

* (6) Maturity + Others + Time FE | Firm Controls [Yes], Aggregate Control [Yes]
set more off
xtset gvkey time
reghdfe inv tsum (c.l.temp_maturity)#(c.tsum) (c.tsum)#(c.l.temp_leverage) (c.tsum)#(c.l.temp_d2default)  ///
        l.temp_maturity l.temp_leverage l.temp_d2default ///
        l.atq l.cheq l.revtq l.saleq l.sale_g l.profit l.vol l.nei ///
		l.vixq l.GDP_Growth l.Unemployment l.inflation, ///
		absorb(time gvkey sic2 quarter) cluster(gvkey time)
estimates store a6, title(A6)

* Export Table 7 in appendix
esttab a1 a2 a3 a4 a5 a6 using 4_results/03_Table_Robustness/Table_a7.tex, replace  ///
se b(3) ar2 starlevels(* .1 ** 0.05 *** 0.01)


************************************************************************
***** Robustness Check NO.3: Alternative Measure ***********************
***** Shocks by Time Window: controlling for cbi ***********************
************************************************************************
replace tsum = mp_jk 

* (1) MP Only  | Firm Control [Yes], Aggregate Control [Yes]
set more off
xtset gvkey time
reghdfe inv tsum l.temp_maturity l.temp_leverage  ///
        l.atq l.cheq l.revtq l.saleq l.sale_g l.profit l.vol l.nei ///
		l.vixq l.GDP_Growth l.Unemployment l.inflation, ///
		absorb(gvkey sic2 quarter) cluster(gvkey time)
estimates store a1, title(A1)

* (2) Maturity Only | Firm Control [Yes], Aggregate Control [Yes]
set more off
xtset gvkey time
reghdfe inv tsum (c.l.temp_maturity)#(c.tsum)  ///
        l.temp_maturity l.temp_leverage   ///
        l.atq l.cheq l.revtq l.saleq l.sale_g l.profit l.vol l.nei ///
		l.vixq l.GDP_Growth l.Unemployment l.inflation, ///
		absorb(gvkey sic2 quarter) cluster(gvkey time)
estimates store a2, title(A2)

* (3) Maturity + Lev + Time FE | Firm Control [Yes], Aggregate Control [Yes]
set more off
xtset gvkey time
reghdfe inv tsum (c.l.temp_maturity)#(c.tsum) (c.tsum)#(c.l.temp_leverage)  ///
        l.temp_maturity l.temp_leverage ///
        l.atq l.cheq l.revtq l.saleq l.sale_g l.profit l.vol l.nei ///
		l.vixq l.GDP_Growth l.Unemployment l.inflation, ///
		absorb(gvkey sic2 quarter time) cluster(gvkey time)
estimates store a3, title(A3)

* (4) Maturity + DD + Time FE| Firm Controls [Yes], Aggregate Control [Yes]
set more off
xtset gvkey time
reghdfe inv tsum (c.l.temp_maturity)#(c.tsum) (c.tsum)#(c.l.temp_d2default)  ///
        l.temp_maturity l.temp_d2default  ///
        l.atq l.cheq l.revtq l.saleq l.sale_g l.profit l.vol l.nei ///
		l.vixq l.GDP_Growth l.Unemployment l.inflation, ///
		absorb(time gvkey sic2 quarter) cluster(gvkey time)
estimates store a4, title(A4)

* (5) Maturity + Others | Firm Control [Yes], Aggregate Control [Yes]
set more off
xtset gvkey time
reghdfe inv tsum (c.l.temp_maturity)#(c.tsum) (c.tsum)#(c.l.temp_leverage) (c.tsum)#(c.l.temp_d2default)  ///
        l.temp_maturity  l.temp_leverage l.temp_d2default ///
        l.atq l.cheq l.revtq l.saleq l.sale_g l.profit l.vol l.nei ///
		l.vixq l.GDP_Growth l.Unemployment l.inflation, ///
		absorb(gvkey sic2 quarter) cluster(gvkey time)
estimates store a5, title(A5)

* (6) Maturity + Others + Time FE | Firm Controls [Yes], Aggregate Control [Yes]
set more off
xtset gvkey time
reghdfe inv tsum (c.l.temp_maturity)#(c.tsum) (c.tsum)#(c.l.temp_leverage) (c.tsum)#(c.l.temp_d2default)  ///
        l.temp_maturity l.temp_leverage l.temp_d2default ///
        l.atq l.cheq l.revtq l.saleq l.sale_g l.profit l.vol l.nei ///
		l.vixq l.GDP_Growth l.Unemployment l.inflation, ///
		absorb(time gvkey sic2 quarter) cluster(gvkey time)
estimates store a6, title(A6)

* Export Table 8 in appendix
esttab a1 a2 a3 a4 a5 a6 using 4_results/03_Table_Robustness/Table_a8.tex, replace  ///
se b(3) ar2 starlevels(* .1 ** 0.05 *** 0.01)


*---------------------------------------------------------------------------------------------
*---------------------------------------------------------------------------------------------
*---------------------------------------------------------------------------------------------
****** Part II:Concerns of Financial Position Measures ---------------------------------------
*---------------------------------------------------------------------------------------------
*---------------------------------------------------------------------------------------------
*---------------------------------------------------------------------------------------------
clear
set more off
use "3_data_constructed/sample.dta",clear
codebook borrow longborrow shortborrow
* reunit size of coff is not tiny
replace atq = atq/1000000

*----------------------------------------------------------------------
* Takeout Average Mean
replace leverage = leverage-0.351701
replace maturity = maturity-0.8421202

*----------------------------------------------------------------------
*sort gvkey time
*gen counting = 1 
*bysort gvkey: egen counts = total(counting)
*drop if counts<10

*----------------------------------------------------------------------
egen mean_leverage=mean(leverage), by (gvkey)
egen mean_maturity=mean(maturity), by (gvkey)
egen mean_d2default=mean(d2default), by (gvkey)
egen mean_liquidity=mean(liquidity), by (gvkey)
gen temp_leverage=leverage - mean_leverage
gen temp_maturity=maturity - mean_maturity
gen temp_d2default=d2default - mean_d2default
gen temp_liquidity=liquidity - mean_liquidity

************************************************************************
***** Robustness Check NO.4: Not Demeaned Financial Positions **********
************************************************************************

* (1) MP Only  | Firm Control [Yes], Aggregate Control [Yes]
set more off
xtset gvkey time
reghdfe inv tsum l.maturity l.leverage  ///
        l.atq l.cheq l.revtq l.saleq l.sale_g l.profit l.vol l.nei ///
		l.vixq l.GDP_Growth l.Unemployment l.inflation, ///
		absorb(gvkey sic2 quarter) cluster(gvkey time)
estimates store a1, title(A1)

* (2) Maturity Only | Firm Control [Yes], Aggregate Control [Yes]
set more off
xtset gvkey time
reghdfe inv tsum (c.l.maturity)#(c.tsum)  ///
        l.maturity l.leverage   ///
        l.atq l.cheq l.revtq l.saleq l.sale_g l.profit l.vol l.nei ///
		l.vixq l.GDP_Growth l.Unemployment l.inflation, ///
		absorb(gvkey sic2 quarter) cluster(gvkey time)
estimates store a2, title(A2)

* (3) Maturity + Lev + Time FE | Firm Control [Yes], Aggregate Control [Yes]
set more off
xtset gvkey time
reghdfe inv tsum (c.l.maturity)#(c.tsum) (c.tsum)#(c.l.leverage)  ///
        l.maturity l.leverage ///
        l.atq l.cheq l.revtq l.saleq l.sale_g l.profit l.vol l.nei ///
		l.vixq l.GDP_Growth l.Unemployment l.inflation, ///
		absorb(gvkey sic2 quarter time) cluster(gvkey time)
estimates store a3, title(A3)

* (4) Maturity + DD + Time FE| Firm Controls [Yes], Aggregate Control [Yes]
set more off
xtset gvkey time
reghdfe inv tsum (c.l.maturity)#(c.tsum) (c.tsum)#(c.l.d2default)  ///
        l.maturity l.d2default ///
        l.atq l.cheq l.revtq l.saleq l.sale_g l.profit l.vol l.nei ///
		l.vixq l.GDP_Growth l.Unemployment l.inflation, ///
		absorb(time gvkey sic2 quarter) cluster(gvkey time)
estimates store a4, title(A4)

* (5) Maturity + Others | Firm Control [Yes], Aggregate Control [Yes]
set more off
xtset gvkey time
reghdfe inv tsum (c.l.maturity)#(c.tsum) (c.tsum)#(c.l.leverage) (c.tsum)#(c.l.d2default)  ///
        l.maturity  l.leverage l.d2default ///
        l.atq l.cheq l.revtq l.saleq l.sale_g l.profit l.vol l.nei ///
		l.vixq l.GDP_Growth l.Unemployment l.inflation, ///
		absorb(gvkey sic2 quarter) cluster(gvkey time)
estimates store a5, title(A5)

* (6) Maturity + Others + Time FE | Firm Controls [Yes], Aggregate Control [Yes]
set more off
xtset gvkey time
reghdfe inv tsum (c.l.maturity)#(c.tsum) (c.tsum)#(c.l.leverage) (c.tsum)#(c.l.d2default)  ///
        l.maturity l.leverage l.d2default ///
        l.atq l.cheq l.revtq l.saleq l.sale_g l.profit l.vol l.nei ///
		l.vixq l.GDP_Growth l.Unemployment l.inflation, ///
		absorb(time gvkey sic2 quarter) cluster(gvkey time)
estimates store a6, title(A5)

* Export Table 9 in appendix
esttab a1 a2 a3 a4 a5 a6 using 4_results/03_Table_Robustness/Table_a9.tex, replace  ///
se b(3) ar2 starlevels(* .1 ** 0.05 *** 0.01)


************************************************************************
***** Robustness Check NO.5: Permonent Financial Positions **********
************************************************************************

* (1) MP Only  | Firm Control [Yes], Aggregate Control [Yes]
set more off
xtset gvkey time
reghdfe inv tsum l.mean_maturity l.mean_leverage  ///
        l.atq l.cheq l.revtq l.saleq l.sale_g l.profit l.vol l.nei ///
		l.vixq l.GDP_Growth l.Unemployment l.inflation, ///
		absorb(gvkey sic2 quarter) cluster(gvkey time)
estimates store a1, title(A1)

* (2) Maturity Only | Firm Control [Yes], Aggregate Control [Yes]
set more off
xtset gvkey time
reghdfe inv tsum (c.l.mean_maturity)#(c.tsum)  ///
        l.mean_maturity l.mean_leverage   ///
        l.atq l.cheq l.revtq l.saleq l.sale_g l.profit l.vol l.nei ///
		l.vixq l.GDP_Growth l.Unemployment l.inflation, ///
		absorb(gvkey sic2 quarter) cluster(gvkey time)
estimates store a2, title(A2)

* (3) Maturity + Lev + Time FE | Firm Control [Yes], Aggregate Control [Yes]
set more off
xtset gvkey time
reghdfe inv tsum (c.l.mean_maturity)#(c.tsum) (c.tsum)#(c.l.mean_leverage)  ///
        l.mean_maturity l.mean_leverage ///
        l.atq l.cheq l.revtq l.saleq l.sale_g l.profit l.vol l.nei ///
		l.vixq l.GDP_Growth l.Unemployment l.inflation, ///
		absorb(gvkey sic2 quarter time) cluster(gvkey time)
estimates store a3, title(A3)

* (4) Maturity + DD + Time FE| Firm Controls [Yes], Aggregate Control [Yes]
set more off
xtset gvkey time
reghdfe inv tsum (c.l.mean_maturity)#(c.tsum) (c.tsum)#(c.l.mean_d2default)  ///
        l.mean_maturity l.mean_d2default ///
        l.atq l.cheq l.revtq l.saleq l.sale_g l.profit l.vol l.nei ///
		l.vixq l.GDP_Growth l.Unemployment l.inflation, ///
		absorb(time gvkey sic2 quarter) cluster(gvkey time)
estimates store a4, title(A4)

* (5) Maturity + Others | Firm Control [Yes], Aggregate Control [Yes]
set more off
xtset gvkey time
reghdfe inv tsum (c.l.mean_maturity)#(c.tsum) (c.tsum)#(c.l.mean_leverage) (c.tsum)#(c.l.mean_d2default)  ///
        l.mean_maturity l.mean_leverage l.mean_d2default ///
        l.atq l.cheq l.revtq l.saleq l.sale_g l.profit l.vol l.nei ///
		l.vixq l.GDP_Growth l.Unemployment l.inflation, ///
		absorb(gvkey sic2 quarter) cluster(gvkey time)
estimates store a5, title(A5)

* (6) Maturity + Others + Time FE | Firm Controls [Yes], Aggregate Control [Yes]
set more off
xtset gvkey time
reghdfe inv tsum (c.l.mean_maturity)#(c.tsum) (c.tsum)#(c.l.mean_leverage) (c.tsum)#(c.l.mean_d2default)  ///
        l.mean_maturity l.mean_leverage l.mean_d2default ///
        l.atq l.cheq l.revtq l.saleq l.sale_g l.profit l.vol l.nei ///
		l.vixq l.GDP_Growth l.Unemployment l.inflation, ///
		absorb(time gvkey sic2 quarter) cluster(gvkey time)
estimates store a6, title(A5)

* Export Table 10 in appendix
esttab a1 a2 a3 a4 a5 a6 using 4_results/03_Table_Robustness/Table_a10.tex, replace  ///
se b(3) ar2 starlevels(* .1 ** 0.05 *** 0.01)


************************************************************************
***** Robustness Check NO.6: Other Financial Positions **********
************************************************************************

* (1) leverage
set more off
xtset gvkey time
reghdfe inv tsum (c.l.temp_maturity)#(c.tsum) ///
                 (c.tsum)#(c.l.temp_leverage)  ///
                 l.temp_maturity l.temp_leverage ///
                 l.atq l.cheq l.revtq l.saleq l.sale_g l.profit l.vol l.nei ///
				 l.vixq l.GDP_Growth l.Unemployment l.inflation, ///
		         absorb(gvkey sic2 quarter time) cluster(gvkey time)
estimates store a1

* (2) d2default
set more off
xtset gvkey time
reghdfe inv tsum (c.l.temp_maturity)#(c.tsum) ///
                 (c.tsum)#(c.l.temp_d2default)  ///
                 l.temp_maturity l.temp_leverage  ///
                 l.atq l.cheq l.revtq l.saleq l.sale_g l.profit l.vol l.nei ///
				 l.vixq l.GDP_Growth l.Unemployment l.inflation, ///
		         absorb(time gvkey sic2 quarter) cluster(gvkey time)
estimates store a2

* (3) LIQUIDITY		
set more off
xtset gvkey time
reghdfe inv tsum (c.tsum)#(c.l.temp_maturity) ///
                 (c.tsum)#(c.l.temp_liquidity) ///
                 l.temp_maturity l.atq ///
                 l.cheq l.revtq l.saleq l.sale_g l.profit l.vol l.nei ///
                 l.vixq l.GDP_Growth l.Unemployment l.inflation, ///
		         absorb(time gvkey sic2 quarter) cluster(gvkey time)
estimates store a3

* (4) AGE
set more off
xtset gvkey time
reghdfe inv tsum (c.tsum)#(c.l.temp_maturity) ///
                 (c.tsum)#(c.l.age) ///
                 l.temp_maturity l.age l.atq ///
                 l.cheq l.revtq l.saleq l.sale_g l.profit l.vol l.nei ///
                 l.vixq l.GDP_Growth l.Unemployment l.inflation, ///
		         absorb(time gvkey sic2 quarter) cluster(gvkey time)
estimates store a4

* (5) SIZE (adjust units)
set more off
xtset gvkey time
reghdfe inv tsum (c.tsum)#(c.l.temp_maturity) ///
                 (c.tsum)#(c.l.atq) ///
                 l.temp_maturity l.atq ///
                 l.cheq l.revtq l.saleq l.sale_g l.profit l.vol l.nei ///
                 l.vixq l.GDP_Growth l.Unemployment l.inflation, ///
		         absorb(time gvkey sic2 quarter) cluster(gvkey time)
estimates store a5

* (6) ALL?
set more off
xtset gvkey time
reghdfe inv tsum (c.tsum)#(c.l.temp_maturity) ///
                 (c.tsum)#(c.l.temp_leverage)  ///
				 (c.tsum)#(c.l.temp_d2default)  ///
				 (c.tsum)#(c.l.temp_liquidity) ///
				 (c.tsum)#(c.l.age) ///
                 (c.tsum)#(c.l.atq) ///
                 l.temp_maturity l.temp_leverage l.temp_d2default l.age l.atq ///
                 l.cheq l.revtq l.saleq l.sale_g l.profit l.vol l.nei ///
                 l.vixq l.GDP_Growth l.Unemployment l.inflation, ///
		         absorb(time gvkey sic2 quarter) cluster(gvkey time)
estimates store a6

* Export Table 11 in appendix
esttab a1 a2 a3 a4 a5 a6 using 4_results/03_Table_Robustness/Table_a11.tex, replace  ///
se b(3) ar2 starlevels(* .1 ** 0.05 *** 0.01)


************************************************************************
***** Robustness Check NO.7: Dynamic Panel (Past Inv) **********
************************************************************************

* (1) MP Only  | Firm Control [Yes], Aggregate Control [Yes]
set more off
xtset gvkey time
reghdfe inv tsum l.temp_maturity l.temp_leverage  ///
        l.inv l2.inv l3.inv l4.inv ///
        l.atq l.cheq l.revtq l.saleq l.sale_g l.profit l.vol l.nei ///
		l.vixq l.GDP_Growth l.Unemployment l.inflation, ///
		absorb(gvkey sic2 quarter) cluster(gvkey time)
estimates store a1, title(A1)

* (2) Maturity Only | Firm Control [Yes], Aggregate Control [Yes]
set more off
xtset gvkey time
reghdfe inv tsum (c.l.temp_maturity)#(c.tsum)  ///
        l.inv l2.inv l3.inv l4.inv ///
        l.temp_maturity l.temp_leverage   ///
        l.atq l.cheq l.revtq l.saleq l.sale_g l.profit l.vol l.nei ///
		l.vixq l.GDP_Growth l.Unemployment l.inflation, ///
		absorb(gvkey sic2 quarter) cluster(gvkey time)
estimates store a2, title(A2)

* (3) Maturity + Lev + Time FE | Firm Control [Yes], Aggregate Control [Yes]
set more off
xtset gvkey time
reghdfe inv tsum (c.l.temp_maturity)#(c.tsum) (c.tsum)#(c.l.temp_leverage)  ///
        l.inv l2.inv l3.inv l4.inv ///
        l.temp_maturity l.temp_leverage ///
        l.atq l.cheq l.revtq l.saleq l.sale_g l.profit l.vol l.nei ///
		l.vixq l.GDP_Growth l.Unemployment l.inflation, ///
		absorb(gvkey sic2 quarter time) cluster(gvkey time)
estimates store a3, title(A3)

* (4) Maturity + DD + Time FE| Firm Controls [Yes], Aggregate Control [Yes]
set more off
xtset gvkey time
reghdfe inv tsum (c.l.temp_maturity)#(c.tsum) (c.tsum)#(c.l.temp_d2default)  ///
        l.inv l2.inv l3.inv l4.inv ///
        l.temp_maturity l.temp_d2default ///
        l.atq l.cheq l.revtq l.saleq l.sale_g l.profit l.vol l.nei ///
		l.vixq l.GDP_Growth l.Unemployment l.inflation, ///
		absorb(time gvkey sic2 quarter) cluster(gvkey time)
estimates store a4, title(A4)

* (5) Maturity + Others | Firm Control [Yes], Aggregate Control [Yes]
set more off
xtset gvkey time
reghdfe inv tsum (c.l.temp_maturity)#(c.tsum) (c.tsum)#(c.l.temp_leverage) (c.tsum)#(c.l.temp_d2default)  ///
        l.inv l2.inv l3.inv l4.inv ///
        l.temp_maturity  l.temp_leverage l.temp_d2default ///
        l.atq l.cheq l.revtq l.saleq l.sale_g l.profit l.vol l.nei ///
		l.vixq l.GDP_Growth l.Unemployment l.inflation, ///
		absorb(gvkey sic2 quarter) cluster(gvkey time)
estimates store a5, title(A5)

* (6) Maturity + Others + Time FE | Firm Controls [Yes], Aggregate Control [Yes]
set more off
xtset gvkey time
reghdfe inv tsum (c.l.temp_maturity)#(c.tsum) (c.tsum)#(c.l.temp_leverage) (c.tsum)#(c.l.temp_d2default)  ///
        l.inv l2.inv l3.inv l4.inv ///
        l.temp_maturity l.temp_leverage l.temp_d2default ///
        l.atq l.cheq l.revtq l.saleq l.sale_g l.profit l.vol l.nei ///
		l.vixq l.GDP_Growth l.Unemployment l.inflation, ///
		absorb(time gvkey sic2 quarter) cluster(gvkey time)
estimates store a6, title(A5)

* Export Table 12 in appendix
esttab a1 a2 a3 a4 a5 a6 using 4_results/03_Table_Robustness/Table_a12.tex, replace  ///
se b(3) ar2 starlevels(* .1 ** 0.05 *** 0.01)




