**********************************************
****** Part I: Clean Credit Rating ***********
**********************************************
clear
set more off
*-----------------------------------------------------------------------------------
*** Clean Credit Rating
clear
use 2_data_raw/credit_rating_raw.dta
drop spsdrm
*-- Longrating
gen longrating = 22 if splticrm=="AAA"
replace longrating = 21 if splticrm=="AA+"
replace longrating = 20 if splticrm=="AA"
replace longrating = 19 if splticrm=="AA-"
replace longrating = 18 if splticrm=="A+"
replace longrating = 17 if splticrm=="A"
replace longrating = 16 if splticrm=="A-"
replace longrating = 15 if splticrm=="BBB+"
replace longrating = 14 if splticrm=="BBB"
replace longrating = 13 if splticrm=="BBB-"
replace longrating = 12 if splticrm=="BB+"
replace longrating = 11 if splticrm=="BB"
replace longrating = 10 if splticrm=="BB-"
replace longrating = 9 if splticrm=="B+"
replace longrating = 8 if splticrm=="B-"
replace longrating = 7 if splticrm=="B-"
replace longrating = 6 if splticrm=="CCC+"
replace longrating = 5 if splticrm=="CCC"
replace longrating = 4 if splticrm=="CCC-"
replace longrating = 3 if splticrm=="CC"
replace longrating = 2 if splticrm=="D"
replace longrating = 1 if splticrm=="SD"
*-- Shortrating
gen shortrating = 10 if spsticrm == "A-1+"
replace shortrating = 9 if spsticrm == "A-1"
replace shortrating = 8 if spsticrm == "A-2"
replace shortrating = 7 if spsticrm == "A-3"
replace shortrating = 6 if spsticrm == "B"
replace shortrating = 5 if spsticrm == "B-1"
replace shortrating = 4 if spsticrm == "B-2"
replace shortrating = 3 if spsticrm == "B-3"
replace shortrating = 2 if spsticrm == "C"
replace shortrating = 1 if spsticrm == "D"
*-- Missing Data
drop if longrating==. & shortrating==.
*-- Quarterly Average
gen year=year(datadate)
gen month=month(datadate)
gen quarter=1 if month==2 
replace quarter=2 if  month==5 
replace quarter=3 if  month==8 
replace quarter=4 if  month==11 
sort gvkey year quarter
*-- Final Adjust
drop datadate month splticrm spsticrm
drop if quarter==.
duplicates drop
destring gvkey, replace
save 5_temp/creditrating.dta,replace

*-----------------------------------------------------------------------------------
*** Merge sample
clear
set more off
use 5_temp/creditrating.dta
sort gvkey year quarter
merge 1:1 gvkey year quarter using 3_data_constructed/sample.dta
keep if _merge==3
drop _merge
save 3_data_constructed/creditrating.dta, replace


**********************************************
****** Part II: Use Credit Rating ************
**********************************************

 
*-----------------------------------------------------------------------------------
*** Maturity By Groups PLOT
clear
set more off
use 3_data_constructed/creditrating.dta
egen mat_group = xtile(maturity) , nq(3) 
*drop x1 x2 x3 cr1 cr2 cr3
kdensity longrating if mat_group==1, nograph generate(x1 cr1) 
kdensity longrating if mat_group==2, nograph generate(x2 cr2) 
kdensity longrating if mat_group==3, nograph generate(x3 cr3) 
line cr1 cr2 cr3 x1, sort ytitle(Density) legend(cols(1))
gr_edit .xaxis1.reset_rule 1 22 2 , tickset(major) ruletype(range) 
gr_edit .xaxis1.style.editstyle draw_major_grid(yes) editcopy
gr_edit .xaxis1.reset_rule 1 22 2 , tickset(major) ruletype(range) 
gr_edit .xaxis1.title.text = {}
gr_edit .xaxis1.title.text.Arrpush Credit Rating by Maturity (Highest on the Right)
gr_edit .legend.plotregion1.label[1].text = {}
gr_edit .legend.plotregion1.label[1].text.Arrpush Short Maturity
gr_edit .legend.plotregion1.label[2].text = {}
gr_edit .legend.plotregion1.label[2].text.Arrpush Med Maturity
gr_edit .legend.plotregion1.label[3].text = {}
gr_edit .legend.plotregion1.label[3].text.Arrpush Long Maturity
gr_edit .yaxis1.style.editstyle draw_major_grid(yes) editcopy
gr_edit .style.editstyle declared_ysize(6) editcopy
gr_edit .style.editstyle declared_xsize(6) editcopy
gr_edit .plotregion1.plot1.style.editstyle line(color(midblue)) editcopy
gr_edit .plotregion1.plot1.style.editstyle line(width(medthick)) editcopy
gr_edit .plotregion1.plot1.style.editstyle line(pattern(longdash)) editcopy
gr_edit .plotregion1.plot3.style.editstyle line(color(maroon)) editcopy
gr_edit .plotregion1.plot3.style.editstyle line(width(medthick)) editcopy
gr_edit .plotregion1.plot3.style.editstyle line(color(orange_red)) editcopy
gr_edit .plotregion1.plot2.style.editstyle line(color(orange)) editcopy
gr_edit .plotregion1.plot2.style.editstyle line(width(medthick)) editcopy
gr_edit .plotregion1.plot2.style.editstyle line(pattern(dash)) editcopy
gr_edit .plotregion1.plot3.style.editstyle line(color(red)) editcopy
graph save 4_results/01_Graph/Figure_a2.gph, replace
graph export 4_results/01_Graph/Figure_a2.eps, replace

 
*-----------------------------------------------------------------------------------
*** 3D PLOT 1
clear
set more off
use 3_data_constructed/creditrating.dta
*** gen
egen mat_3d_y = xtile(maturity) , nq(10) 
egen lev_3d_x = xtile(leverage) , nq(10) 
egen d2d_3d_x = xtile(d2d) , nq(10)
bysort lev_3d_x mat_3d_y: egen rat_3d_z = mean(longrating)
keep rat_3d_z lev_3d_x  mat_3d_y
duplicates drop 
hexplot rat_3d_z lev_3d_x  mat_3d_y, color(PiYG) sizeprop recenter  
gr_edit .legend.subtitle.text = {}
gr_edit .legend.subtitle.text.Arrpush Credit Rating
gr_edit .xaxis1.title.text = {}
gr_edit .xaxis1.title.text.Arrpush Maturity by Decile
gr_edit .yaxis1.title.text = {}
gr_edit .yaxis1.title.text.Arrpush Leverage by Decile
gr_edit .xaxis1.reset_rule 1 10 1 , tickset(major) ruletype(range) 
gr_edit .xaxis1.reset_rule 1 10 1 , tickset(major) ruletype(range) 
gr_edit .yaxis1.reset_rule 1 10 1 , tickset(major) ruletype(range) 
gr_edit .yaxis1.reset_rule 1 10 1 , tickset(major) ruletype(range) 
graph save 4_results/01_Graph/Figure_3a.gph, replace
graph export 4_results/01_Graph/Figure_3a.eps, replace


*-----------------------------------------------------------------------------------
*** 3D PLOT 2
clear
set more off
use 3_data_constructed/creditrating.dta
*** gen
egen mat_3d_y = xtile(maturity) , nq(10)  
egen d2d_3d_x = xtile(d2d) , nq(10)
bysort d2d_3d_x mat_3d_y: egen rat_3d_z = mean(longrating)
keep rat_3d_z d2d_3d_x mat_3d_y
duplicates drop 
hexplot rat_3d_z d2d_3d_x mat_3d_y, color(PiYG) sizeprop recenter  
gr_edit .legend.subtitle.text = {}
gr_edit .legend.subtitle.text.Arrpush Credit Rating
gr_edit .xaxis1.title.text = {}
gr_edit .xaxis1.title.text.Arrpush Maturity by Decile
gr_edit .yaxis1.title.text = {}
gr_edit .yaxis1.title.text.Arrpush Dis.-to-Default by Decile
gr_edit .xaxis1.reset_rule 1 10 1 , tickset(major) ruletype(range) 
gr_edit .xaxis1.reset_rule 1 10 1 , tickset(major) ruletype(range) 
gr_edit .yaxis1.reset_rule 1 10 1 , tickset(major) ruletype(range) 
gr_edit .yaxis1.reset_rule 1 10 1 , tickset(major) ruletype(range) 
graph save 4_results/01_Graph/Figure_3b.gph, replace
graph export 4_results/01_Graph/Figure_3b.eps, replace


*-----------------------------------------------------------------------------------
*** REGRESSION 1
clear
set more off
use 3_data_constructed/creditrating.dta

* (1) Maturity Only 
set more off
xtset gvkey time
xi: xtreg longrating  l.maturity  l.atq l.cheq l.revtq l.saleq l.sale_g  l.profit l.vol l.nei  ///
    l.vixq l.GDP_Growth l.Unemployment l.inflation i.sic2 i.quarter,fe cluster(sic2)
estimates store b1, title(A2)

* (2) Leverage Only 
set more off
xtset gvkey time
xi: xtreg longrating l.leverage l.atq l.cheq l.revtq l.saleq l.sale_g  l.profit l.vol l.nei  ///
    l.vixq l.GDP_Growth l.Unemployment l.inflation i.sic2 i.quarter,fe cluster(sic2)
estimates store b2, title(A1)

* (3) D2D Only 
set more off
xtset gvkey time
xi: xtreg longrating l.d2d l.atq l.cheq l.revtq l.saleq l.sale_g  l.profit l.vol l.nei  ///
    l.vixq l.GDP_Growth l.Unemployment l.inflation i.sic2 i.quarter,fe cluster(sic2)
estimates store b3, title(A1)

* (4) Joint 
set more off
xtset gvkey time
xi: xtreg longrating  l.maturity  l.leverage l.d2d l.atq l.cheq l.revtq l.saleq l.sale_g  l.profit l.vol l.nei  ///
    l.vixq l.GDP_Growth l.Unemployment l.inflation i.sic2 i.quarter,fe cluster(sic2)
estimates store b4, title(A3)

* Export Table 13 in appendix
esttab b1 b2 b3 b4 using 4_results/03_Table_Robustness/Table_a13.tex, replace ///
b(2) r2 ar2 starlevels(* .1 ** 0.05 *** 0.01)


*-----------------------------------------------------------------------------------
*** REGRESSION 2 Credit Rating on Investment
clear
set more off
use 3_data_constructed/creditrating.dta
 
*-- A vs <A
gen good=1 if longrating>=17
replace good=0 if longrating<17

*-- Takeout Average Mean
replace leverage = leverage-0.351701
replace maturity = maturity-0.8421202

*-- Demeaned
egen mean_leverage=mean(leverage), by (gvkey)
egen mean_maturity=mean(maturity), by (gvkey)
egen mean_d2default=mean(d2default), by (gvkey)
egen mean_age=mean(age), by (gvkey)
egen mean_liquidity=mean(liquidity), by (gvkey)
gen temp_leverage=leverage - mean_leverage
gen temp_maturity=maturity - mean_maturity
gen temp_d2default=d2default - mean_d2default
gen temp_age=age - mean_age
gen temp_liquidity=liquidity - mean_liquidity

*----------------------------------------------------------------------
****** Table 4: The Temp Departs 

* (1) MP Only  | Firm Control [Yes], Aggregate Control [Yes]
set more off
xtset gvkey time
reghdfe inv tsum l.temp_maturity l.temp_leverage  ///
        l.atq l.cheq l.revtq l.saleq l.sale_g l.profit l.vol l.nei ///
		l.vixq l.GDP_Growth l.Unemployment l.inflation, ///
		absorb(gvkey sic2 quarter) cluster(gvkey time)
estimates store a1, title(A1)

* (2) Maturity Only | Firm Control [Yes], Aggregate Control [Yes]
set more off
xtset gvkey time
reghdfe inv tsum (c.l.temp_maturity)#(c.tsum)  (c.l.good)#(c.tsum) ///
        l.temp_maturity l.temp_leverage l.good  ///
        l.atq l.cheq l.revtq l.saleq l.sale_g l.profit l.vol l.nei ///
		l.vixq l.GDP_Growth l.Unemployment l.inflation, ///
		absorb(gvkey sic2 quarter) cluster(gvkey time)
estimates store a2, title(A2)

* (3) Maturity + Lev + Time FE | Firm Control [Yes], Aggregate Control [Yes]
set more off
xtset gvkey time
reghdfe inv tsum (c.l.temp_maturity)#(c.tsum) (c.tsum)#(c.l.temp_leverage) ///
        (c.l.good)#(c.tsum) ///
        l.temp_maturity l.temp_leverage l.good ///
        l.atq l.cheq l.revtq l.saleq l.sale_g l.profit l.vol l.nei ///
		l.vixq l.GDP_Growth l.Unemployment l.inflation, ///
		absorb(gvkey sic2 quarter time) cluster(gvkey time)
estimates store a3, title(A3)

* (4) Maturity + DD + Time FE| Firm Controls [Yes], Aggregate Control [Yes]
set more off
xtset gvkey time
reghdfe inv tsum (c.l.temp_maturity)#(c.tsum) (c.tsum)#(c.l.temp_d2default) (c.l.good)#(c.tsum) ///
        l.temp_maturity l.good l.temp_d2default ///
        l.atq l.cheq l.revtq l.saleq l.sale_g l.profit l.vol l.nei ///
		l.vixq l.GDP_Growth l.Unemployment l.inflation, ///
		absorb(time gvkey sic2 quarter) cluster(gvkey time)
estimates store a4, title(A4)

* (5) Maturity + Others | Firm Control [Yes], Aggregate Control [Yes]
set more off
xtset gvkey time
reghdfe inv tsum (c.l.temp_maturity)#(c.tsum) (c.tsum)#(c.l.temp_leverage) ///
        (c.tsum)#(c.l.temp_d2default) (c.l.good)#(c.tsum) ///
        l.temp_maturity  l.temp_leverage  l.temp_d2default l.good ///
        l.atq l.cheq l.revtq l.saleq l.sale_g l.profit l.vol l.nei ///
		l.vixq l.GDP_Growth l.Unemployment l.inflation, ///
		absorb(gvkey sic2 quarter) cluster(gvkey time)
estimates store a5, title(A4)

* (6) Maturity + Others + Time FE | Firm Controls [Yes], Aggregate Control [Yes]
set more off
xtset gvkey time
reghdfe inv tsum (c.l.temp_maturity)#(c.tsum) (c.tsum)#(c.l.temp_leverage) ///
        (c.tsum)#(c.l.temp_d2default) (c.l.good)#(c.tsum) ///
        l.temp_maturity  l.temp_leverage  l.temp_d2default l.good ///
        l.atq l.cheq l.revtq l.saleq l.sale_g l.profit l.vol l.nei ///
		l.vixq l.GDP_Growth l.Unemployment l.inflation, ///
		absorb(time gvkey sic2 quarter) cluster(gvkey time)
estimates store a6, title(A5)

* Export Table 4
esttab a1 a2 a3 a4 a5 a6 using 4_results/02_Table_Main/Table_4.tex, replace  ///
se b(3) ar2 starlevels(* .1 ** 0.05 *** 0.01)








