* We are going to look at how firms responses to monetary policy shocks gien their financial positions
* Financial positions we are discussing here is (leverage, maturity)
* Firms responses are (investment, borrowing, leverage choice, maturity choice)
clear
set more off
use "3_data_constructed/sample.dta",clear
codebook borrow longborrow shortborrow

*----------------------------------------------------------------------
* Takeout Average Mean
replace leverage = leverage-0.351701
replace maturity = maturity-0.8421202

*----------------------------------------------------------------------
egen mean_leverage=mean(leverage), by (gvkey)
egen mean_maturity=mean(maturity), by (gvkey)
egen mean_d2default=mean(d2default), by (gvkey)
egen mean_age=mean(age), by (gvkey)
egen mean_liquidity=mean(liquidity), by (gvkey)
gen temp_leverage=leverage - mean_leverage
gen temp_maturity=maturity - mean_maturity
gen temp_d2default=d2default - mean_d2default
gen temp_age=age - mean_age
gen temp_liquidity=liquidity - mean_liquidity

*----------------------------------------------------------------------
****** Table 5: The Temp Departs 

* (1) MP Only  | Firm Control [Yes], Aggregate Control [Yes]
set more off
xtset gvkey time
reghdfe borrow tsum l.temp_maturity l.temp_leverage  ///
        l.atq l.cheq l.revtq l.saleq l.sale_g l.profit l.vol l.nei ///
		l.vixq l.GDP_Growth l.Unemployment l.inflation, ///
		absorb(gvkey sic2 quarter) cluster(gvkey time)
estimates store a1, title(A1)

* (2) Maturity Only | Firm Control [Yes], Aggregate Control [Yes]
set more off
xtset gvkey time
reghdfe borrow tsum (c.l.temp_maturity)#(c.tsum)  ///
        l.temp_maturity l.temp_leverage   ///
        l.atq l.cheq l.revtq l.saleq l.sale_g l.profit l.vol l.nei ///
		l.vixq l.GDP_Growth l.Unemployment l.inflation, ///
		absorb(gvkey sic2 quarter) cluster(gvkey time)
estimates store a2, title(A2)

* (3) Maturity + Lev + Time FE | Firm Control [Yes], Aggregate Control [Yes]
set more off
xtset gvkey time
reghdfe borrow tsum (c.l.temp_maturity)#(c.tsum) (c.tsum)#(c.l.temp_leverage)  ///
        l.temp_maturity l.temp_leverage ///
        l.atq l.cheq l.revtq l.saleq l.sale_g l.profit l.vol l.nei ///
		l.vixq l.GDP_Growth l.Unemployment l.inflation, ///
		absorb(gvkey sic2 quarter time) cluster(gvkey time)
estimates store a3, title(A3)

* (4) Maturity + DD + Time FE | Firm Controls [Yes], Aggregate Control [Yes]
set more off
xtset gvkey time
reghdfe borrow tsum (c.l.temp_maturity)#(c.tsum) (c.tsum)#(c.l.temp_d2default)  ///
        l.temp_maturity l.temp_leverage l.temp_d2default ///
        l.atq l.cheq l.revtq l.saleq l.sale_g l.profit l.vol l.nei ///
		l.vixq l.GDP_Growth l.Unemployment l.inflation, ///
		absorb(time gvkey sic2 quarter) cluster(gvkey time)
estimates store a4, title(A4)

* (5) Maturity + Others | Firm Control [Yes], Aggregate Control [Yes]
set more off
xtset gvkey time
reghdfe borrow tsum (c.l.temp_maturity)#(c.tsum) (c.tsum)#(c.l.temp_leverage) (c.tsum)#(c.l.temp_d2default)  ///
        l.temp_maturity  l.temp_leverage l.temp_d2default ///
        l.atq l.cheq l.revtq l.saleq l.sale_g l.profit l.vol l.nei ///
		l.vixq l.GDP_Growth l.Unemployment l.inflation, ///
		absorb(gvkey sic2 quarter) cluster(gvkey time)
estimates store a5, title(A5)

* (6) Maturity + Others + Time FE| Firm Controls [Yes], Aggregate Control [Yes]
set more off
xtset gvkey time
reghdfe borrow tsum (c.l.temp_maturity)#(c.tsum) (c.tsum)#(c.l.temp_leverage) (c.tsum)#(c.l.temp_d2default)  ///
        l.temp_maturity l.temp_leverage l.temp_d2default ///
        l.atq l.cheq l.revtq l.saleq l.sale_g l.profit l.vol l.nei ///
		l.vixq l.GDP_Growth l.Unemployment l.inflation, ///
		absorb(time gvkey sic2 quarter) cluster(gvkey time)
estimates store a6, title(A6)

*Export Table 14 in appendix
esttab a1 a2 a3 a4 a5 a6 using 4_results/03_Table_Robustness/Table_14.tex, replace  ///
se b(3) ar2 starlevels(* .1 ** 0.05 *** 0.01)


************************************************************************
******************* LONG VS SHORT Borrowing  ***************************
************************************************************************
replace borrow = longborrow

* (1) MP Only  | Firm Control [Yes], Aggregate Control [Yes]
set more off
xtset gvkey time
reghdfe borrow tsum l.temp_maturity l.temp_leverage  ///
        l.atq l.cheq l.revtq l.saleq l.sale_g l.profit l.vol l.nei ///
		l.vixq l.GDP_Growth l.Unemployment l.inflation, ///
		absorb(gvkey sic2 quarter) cluster(gvkey time)
estimates store a1, title(A1)

* (2) Maturity Only | Firm Control [Yes], Aggregate Control [Yes]
set more off
xtset gvkey time
reghdfe borrow tsum (c.l.temp_maturity)#(c.tsum)  ///
        l.temp_maturity l.temp_leverage   ///
        l.atq l.cheq l.revtq l.saleq l.sale_g l.profit l.vol l.nei ///
		l.vixq l.GDP_Growth l.Unemployment l.inflation, ///
		absorb(gvkey sic2 quarter) cluster(gvkey time)
estimates store a2, title(A2)

* (3) Maturity + Lev + Time FE | Firm Control [Yes], Aggregate Control [Yes]
set more off
xtset gvkey time
reghdfe borrow tsum (c.l.temp_maturity)#(c.tsum) (c.tsum)#(c.l.temp_leverage)  ///
        l.temp_maturity l.temp_leverage ///
        l.atq l.cheq l.revtq l.saleq l.sale_g l.profit l.vol l.nei ///
		l.vixq l.GDP_Growth l.Unemployment l.inflation, ///
		absorb(gvkey sic2 quarter time) cluster(gvkey time)
estimates store a3, title(A3)

* (4) Maturity + DD + Time FE | Firm Controls [Yes], Aggregate Control [Yes]
set more off
xtset gvkey time
reghdfe borrow tsum (c.l.temp_maturity)#(c.tsum) (c.tsum)#(c.l.temp_d2default)  ///
        l.temp_maturity l.temp_leverage l.temp_d2default ///
        l.atq l.cheq l.revtq l.saleq l.sale_g l.profit l.vol l.nei ///
		l.vixq l.GDP_Growth l.Unemployment l.inflation, ///
		absorb(time gvkey sic2 quarter) cluster(gvkey time)
estimates store a4, title(A4)

* (5) Maturity + Others | Firm Control [Yes], Aggregate Control [Yes]
set more off
xtset gvkey time
reghdfe borrow tsum (c.l.temp_maturity)#(c.tsum) (c.tsum)#(c.l.temp_leverage) (c.tsum)#(c.l.temp_d2default)  ///
        l.temp_maturity  l.temp_leverage l.temp_d2default ///
        l.atq l.cheq l.revtq l.saleq l.sale_g l.profit l.vol l.nei ///
		l.vixq l.GDP_Growth l.Unemployment l.inflation, ///
		absorb(gvkey sic2 quarter) cluster(gvkey time)
estimates store a5, title(A5)

* (6) Maturity + Others + Time FE| Firm Controls [Yes], Aggregate Control [Yes]
set more off
xtset gvkey time
reghdfe borrow tsum (c.l.temp_maturity)#(c.tsum) (c.tsum)#(c.l.temp_leverage) (c.tsum)#(c.l.temp_d2default)  ///
        l.temp_maturity l.temp_leverage l.temp_d2default ///
        l.atq l.cheq l.revtq l.saleq l.sale_g l.profit l.vol l.nei ///
		l.vixq l.GDP_Growth l.Unemployment l.inflation, ///
		absorb(time gvkey sic2 quarter) cluster(gvkey time)
estimates store a6, title(A6)

*Export Table 15 in appendix
esttab a1 a2 a3 a4 a5 a6 using 4_results/03_Table_Robustness/Table_a15.tex, replace  ///
se b(3) ar2 starlevels(* .1 ** 0.05 *** 0.01)


*----------------------------------------------------------------------
****** Table 2: SHORT
replace borrow = shortborrow

* (1) MP Only  | Firm Control [Yes], Aggregate Control [Yes]
set more off
xtset gvkey time
reghdfe borrow tsum l.temp_maturity l.temp_leverage  ///
        l.atq l.cheq l.revtq l.saleq l.sale_g l.profit l.vol l.nei ///
		l.vixq l.GDP_Growth l.Unemployment l.inflation, ///
		absorb(gvkey sic2 quarter) cluster(gvkey time)
estimates store a1, title(A1)

* (2) Maturity Only | Firm Control [Yes], Aggregate Control [Yes]
set more off
xtset gvkey time
reghdfe borrow tsum (c.l.temp_maturity)#(c.tsum)  ///
        l.temp_maturity l.temp_leverage   ///
        l.atq l.cheq l.revtq l.saleq l.sale_g l.profit l.vol l.nei ///
		l.vixq l.GDP_Growth l.Unemployment l.inflation, ///
		absorb(gvkey sic2 quarter) cluster(gvkey time)
estimates store a2, title(A2)

* (3) Maturity + Lev + Time FE | Firm Control [Yes], Aggregate Control [Yes]
set more off
xtset gvkey time
reghdfe borrow tsum (c.l.temp_maturity)#(c.tsum) (c.tsum)#(c.l.temp_leverage)  ///
        l.temp_maturity l.temp_leverage ///
        l.atq l.cheq l.revtq l.saleq l.sale_g l.profit l.vol l.nei ///
		l.vixq l.GDP_Growth l.Unemployment l.inflation, ///
		absorb(gvkey sic2 quarter time) cluster(gvkey time)
estimates store a3, title(A3)

* (4) Maturity + DD + Time FE | Firm Controls [Yes], Aggregate Control [Yes]
set more off
xtset gvkey time
reghdfe borrow tsum (c.l.temp_maturity)#(c.tsum) (c.tsum)#(c.l.temp_d2default)  ///
        l.temp_maturity l.temp_leverage l.temp_d2default ///
        l.atq l.cheq l.revtq l.saleq l.sale_g l.profit l.vol l.nei ///
		l.vixq l.GDP_Growth l.Unemployment l.inflation, ///
		absorb(time gvkey sic2 quarter) cluster(gvkey time)
estimates store a4, title(A4)

* (5) Maturity + Others | Firm Control [Yes], Aggregate Control [Yes]
set more off
xtset gvkey time
reghdfe borrow tsum (c.l.temp_maturity)#(c.tsum) (c.tsum)#(c.l.temp_leverage) (c.tsum)#(c.l.temp_d2default)  ///
        l.temp_maturity  l.temp_leverage l.temp_d2default ///
        l.atq l.cheq l.revtq l.saleq l.sale_g l.profit l.vol l.nei ///
		l.vixq l.GDP_Growth l.Unemployment l.inflation, ///
		absorb(gvkey sic2 quarter) cluster(gvkey time)
estimates store a5, title(A5)

* (6) Maturity + Others + Time FE| Firm Controls [Yes], Aggregate Control [Yes]
set more off
xtset gvkey time
reghdfe borrow tsum (c.l.temp_maturity)#(c.tsum) (c.tsum)#(c.l.temp_leverage) (c.tsum)#(c.l.temp_d2default)  ///
        l.temp_maturity l.temp_leverage l.temp_d2default ///
        l.atq l.cheq l.revtq l.saleq l.sale_g l.profit l.vol l.nei ///
		l.vixq l.GDP_Growth l.Unemployment l.inflation, ///
		absorb(time gvkey sic2 quarter) cluster(gvkey time)
estimates store a6, title(A6)

*Export Table 16 in appendix
esttab a1 a2 a3 a4 a5 a6 using 4_results/03_Table_Robustness/Table_a16.tex, replace  ///
se b(3) ar2 starlevels(* .1 ** 0.05 *** 0.01)



*----------------------------------------------------------------------
****** Table 3: LONG VS SHORT

* (1) Long 1
set more off
xtset gvkey time
reghdfe longborrow tsum l.temp_maturity l.temp_leverage  ///
        l.atq l.cheq l.revtq l.saleq l.sale_g l.profit l.vol l.nei ///
		l.vixq l.GDP_Growth l.Unemployment l.inflation, ///
		absorb(gvkey sic2 quarter) cluster(gvkey time)
estimates store a1, title(A1)

* (2) Long 2
set more off
xtset gvkey time
reghdfe longborrow tsum (c.l.temp_maturity)#(c.tsum)  ///
        l.temp_maturity l.temp_leverage   ///
        l.atq l.cheq l.revtq l.saleq l.sale_g l.profit l.vol l.nei ///
		l.vixq l.GDP_Growth l.Unemployment l.inflation, ///
		absorb(gvkey sic2 quarter) cluster(gvkey time)
estimates store a2, title(A2)

* (3) Long 3
set more off
xtset gvkey time
reghdfe longborrow tsum (c.l.temp_maturity)#(c.tsum) (c.tsum)#(c.l.temp_leverage) (c.tsum)#(c.l.temp_d2default)  ///
        l.temp_maturity l.temp_leverage l.temp_d2default ///
        l.atq l.cheq l.revtq l.saleq l.sale_g l.profit l.vol l.nei ///
		l.vixq l.GDP_Growth l.Unemployment l.inflation, ///
		absorb(time gvkey sic2 quarter) cluster(gvkey time)
estimates store a3, title(A3)

* (1) Short 1
set more off
xtset gvkey time
reghdfe shortborrow tsum l.temp_maturity l.temp_leverage  ///
        l.atq l.cheq l.revtq l.saleq l.sale_g l.profit l.vol l.nei ///
		l.vixq l.GDP_Growth l.Unemployment l.inflation, ///
		absorb(gvkey sic2 quarter) cluster(gvkey time)
estimates store a4, title(A4)

* (2) Short 2
set more off
xtset gvkey time
reghdfe shortborrow tsum (c.l.temp_maturity)#(c.tsum)  ///
        l.temp_maturity l.temp_leverage   ///
        l.atq l.cheq l.revtq l.saleq l.sale_g l.profit l.vol l.nei ///
		l.vixq l.GDP_Growth l.Unemployment l.inflation, ///
		absorb(gvkey sic2 quarter) cluster(gvkey time)
estimates store a5, title(A5)

* (3) Short 3
set more off
xtset gvkey time
reghdfe shortborrow tsum (c.l.temp_maturity)#(c.tsum) (c.tsum)#(c.l.temp_leverage) (c.tsum)#(c.l.temp_d2default)  ///
        l.temp_maturity l.temp_leverage l.temp_d2default ///
        l.atq l.cheq l.revtq l.saleq l.sale_g l.profit l.vol l.nei ///
		l.vixq l.GDP_Growth l.Unemployment l.inflation, ///
		absorb(time gvkey sic2 quarter) cluster(gvkey time)
estimates store a6, title(A5)

*Export Table 5
esttab a1 a2 a3 a4 a5 a6 using 4_results/02_Table_Main/Table_5.tex, replace  ///
se b(3) ar2 starlevels(* .1 ** 0.05 *** 0.01)





