
***********************************************
***** Reshape in desired format ****
***********************************************
clear
use investrate.dta
reshape long _, i(index) j(new)
rename index firm
rename new t
rename _ investrate
save reshaped_investrate.dta, replace


clear
use k.dta
reshape long _, i(index) j(new)
rename index firm
rename new t
rename _ k
save reshaped_k.dta, replace

clear
use lev.dta
reshape long _, i(index) j(new)
rename index firm
rename new t
rename _ lev
save reshaped_lev.dta, replace



clear
use f.dta
reshape long _, i(index) j(new)
rename index firm
rename new t
rename _ f
save reshaped_mat.dta, replace

clear
use y.dta
reshape long _, i(index) j(new)
rename index firm
rename new t
rename _ y
save reshaped_y.dta, replace

clear
use r.dta
rename index t
rename _0 r
tsset t
gen shock = r - l.r
save reshaped_r.dta, replace

***********************************************
***** Merge Data ****
***********************************************
clear
use reshaped_investrate.dta
merge 1:1 firm t using reshaped_lev.dta
drop _merge
merge 1:1 firm t using reshaped_mat.dta
keep if _merge==3
drop _merge
merge 1:1 firm t using reshaped_y.dta
keep if _merge==3
drop _merge
merge 1:1 firm t using reshaped_k.dta
keep if _merge==3
drop _merge
merge m:1 t using reshaped_r.dta
keep if _merge==3
drop _merge

sort firm t

* Size: log of total assets
gen size = log(k)

* Sales Growth: log-differences in sales

gen sale_growth = log(y)-log(y[_n-1]) if firm==firm[_n-1]

save regression.dta, replace

***********************************************
***** Regression ****
***********************************************

clear
use regression.dta

replace shock=-shock*10000/15
drop if shock ==.

rename f mat
egen mean_mat = mean(mat), by (firm)
gen demean_mat = mat - mean_mat

egen mean_lev = mean(lev), by (firm)
gen demean_lev = lev - mean_lev


drop if t > 76


tsset firm t
set more off


gen sale = log(y)


xtreg inv (c.l.demean_mat)#(c.shock) l.demean_mat l.lev l.size l.sale l.sale_growth i.t, fe
estimates store a1

xtreg inv (c.l.demean_mat)#(c.shock) (c.l.demean_lev)#(c.shock) l.demean_mat l.demean_lev l.size l.sale l.sale_growth i.t, fe
estimates store a2


esttab a1 a2 using Model_Reg.tex, replace b(3) se r2 ar2 starlevels(* .1 ** 0.05 *** 0.01)
esttab a1 a2 using Model_Reg.txt, replace b(3) se r2 ar2 starlevels(* .1 ** 0.05 *** 0.01)
