
clear
set more off
use regression.dta
xtset firm t

rename f mat

egen mean_mat = mean(mat), by (firm)
gen demean_mat = mat - mean_mat

drop if t > 76

*----------------------------------------------------------------------
** adjust shock
replace shock=-shock*10000/15
drop if shock ==.


*----------------------------------------------------------------------
** adjust logk - logk_t-1
sort firm t
order firm t inv
gen logk = inv if firm != firm[_n-1]
order firm t inv logk
replace logk = logk[_n-1] + inv if logk==. & firm == firm[_n-1]
order firm t inv logk 
                          

**************************************************************
*Local Projections 			
**************************************************************

*******************
** Set-up of LPs **
*******************						  
***** number of lags | horizon
local MaxLPLags 0
local horizon 12					  
						  
***** LHS variable: the response variable
sort firm t
forvalues i=0/`horizon' {
	
	gen logk`i' = (f`i'.logk - l.logk)

}						  
						  
***** variables to store the impulse response 
*(vector of betas from the LP regressions) and standard errors
gen b_mattsum=.
gen b_tsum=.
gen se_mattsum=.
gen se_tsum=.					  


****************************************************************
*** Baseline LP table Using OLS
****************************************************************
***** Gen interaction terms



gen lag_temp_mat_tsum = l.demean_mat*shock

gen sale = log(y)
***** One regression for each horizon of the response (0-12 quarters)
forvalues i=0/`horizon' {	
	
	***** LP regression
	***
	
	xtreg logk`i' shock lag_temp_mat_tsum l.demean_mat l.lev  l.size l.sale l.sale_growth, fe
	eststo ols_logk`i'
	
    replace b_mattsum=_b[lag_temp_mat_tsum]  if _n == `i'+1
    replace se_mattsum=_se[lag_temp_mat_tsum]  if _n == `i'+1

		  
}
	
			
****************************************************************
*** Baseline OLS LP graphs
****************************************************************
local horizon 12	
gen Quarters = _n-1 if _n <= `horizon' +1
* zero line
gen zero = 0 if _n <= `horizon' +1
***** create confidence bands (in this case 90%) ****
scalar sig = 0.10	 // specify significance level	
gen up_mattsum = b_mattsum + invnormal(1-sig/2)*se_mattsum if _n <= (`horizon' + 1)
gen dn_mattsum = b_mattsum - invnormal(1-sig/2)*se_mattsum if _n <= (`horizon' + 1)
	
************************ Plot
	twoway (line b_mattsum Quarters, lcolor(navy) ///
	lpattern(solid) lwidth(medthick)) /// 
	(line up_mattsum Quarters, lcolor(navy) ///
	lpattern(dash) lwidth(thin)) /// 
	(line dn_mattsum Quarters, lcolor(navy) ///
	lpattern(dash) lwidth(thin)) /// 
	(line zero Quarters, lcolor(black)), ///
	ytitle("Interaction coefficient", size(medsmall)) ///
	xtitle("Quarters since shock", size(medsmall)) graphregion(fcolor(white))
	gr_edit .xaxis1.reset_rule 0 12 1 , tickset(major) ruletype(range) 
    gr_edit .xaxis1.style.editstyle draw_major_grid(yes) editcopy
    gr_edit .xaxis1.reset_rule 0 12 1 , tickset(major) ruletype(range) 
    gr_edit .legend.draw_view.setstyle, style(no)
	gr_edit .yaxis1.reset_rule -4 4 2, tickset(major) ruletype(range) 
    gr_edit .yaxis1.style.editstyle draw_major_grid(yes) editcopy	
	gr_edit .yaxis1.reset_rule -6 2 2 , tickset(major) ruletype(range) 
    gr_edit  .yaxis1.reset_rule -6 2 2 , tickset(major) ruletype(range) 

	graph save dynamics_maturity_model.gph, replace
	graph export dynamics_maturity_model.eps, replace
	
